@@ -19,3 +19,5 @@ from je_api_testka.utils.html_report.html_report_generate import generate_html
 # file process
 from je_api_testka.utils.file_process.get_dir_file_list import get_dir_files_as_list
 from je_api_testka.utils.file_process.create_project_structure import create_template_dir
+# graph
+from je_api_testka.utils.create_graph.create_graph import make_tkinter_request_time_graph
